/**
 * @file
 */

(function ($, Drupal, drupalSettings) {

  "use strict";

  Drupal.behaviors.conditional_message = {
    attach: function (context, settings) {
      // Bail if user already closed the message before.
      if (typeof conditional_message_user_closed !== "undefined" && localStorage.getItem(conditional_message_user_closed)) {
        return;
      }
      // Run only once (not on ajax calls).
      if (context != document) {
        return;
      }
      // Shorthand for the configurations.
      let config = drupalSettings.conditional_message;
      let htmls = [];
      // TODO rewrite this in pure JS to avoid jQuery dependency.
      for (let key in config) {
        (function ($, config, key, htmls) {
          queryEndpoint($, config, key, htmls);
        }).call(this, $, config, key, htmls);
      };
    }
  };
})(jQuery, Drupal, drupalSettings);


function queryEndpoint($, config, key, htmls) {
  $.ajax({
    url: config[key].base_path + "conditional_message_data_output", success: function (result) {
      // Checks to see if the message should be displayed.  Config = backend logic, Result = frontend logic.
      var check = [];
      // Check and set sessions with localStorage.
      check['session'] = true;
      var cmrs = 'conditionalMessageReadStatus' + key;
      var readStatus = localStorage.getItem(cmrs);
      if (config[key].conditions.includes('session')) {
        if (readStatus) {
          check['session'] = false;
        }
else {
          localStorage.setItem(cmrs, true);
        }
      }
      // Paths conditions.
      check['path'] = true;
      if (config[key].conditions.includes('path') && result[key].paths.indexOf(window.location.pathname.substr(config[key].base_path.length - 1)) < 0) {
        check['path'] = false;
      }
      // Content type conditions.
      check['type'] = true;
      if (config[key].conditions.includes('content_type') && result[key].hasOwnProperty('types')) {
        check['type'] = false;
        result[key].types.forEach(function (type) {
          var typeClass = 'page-node-type-' + type;
          if ($('body').hasClass(typeClass)) {
            check['type'] = true;
          }
        });
      }
      // Show message if all checks pass.
      if (config[key].status && result[key].display && check['session'] && check['path'] && check['type']) {
        // Build the message HTML.
        let html = '<div class="conditional-message" style="background-color:#'
            + config[key].bg_color + '; color:#'
            + config[key].color + ';">'
            + config[key].message + '<span>X</span></span></div>';
        htmls[key] = html;
        // Place the message in the page top or bottom.
        switch (config[key].position) {
          case  'bottom':
            $(config[key].target).append($(htmls[key]).addClass('conditional-message-bottom'));
            break;

          default:
            $(config[key].target).prepend($(htmls[key]).addClass('conditional-message-top'));
        }
        // Close button.
        $('.conditional-message span').on('click', function () {
          $(this).parent().remove();
          localStorage.setItem(conditional_message_user_closed, true);
        });
      }
    }
  });
}
